==> gatsby-theme-platformos-docskit-1.0.1.tgz: package/gatsby-node.js <==
/**
 * Implement Gatsby's Node APIs in this file.
 *
 * See: https://www.gatsbyjs.com/docs/reference/config-files/gatsby-node/
 */

/**
 * @type {import('gatsby').GatsbyNode['createPages']}
 */
const path = require('path');
const startCase = str => str.replace(/([A-Z])/g, ' $1').replace(/^./, str => str.toUpperCase());

exports.createPages = async ({ actions, graphql, reporter }) => {
  const result = await graphql(
    `
      {
        allMdx(filter: {fields: {source: {eq: "content"}}}) {
          edges {
            node {
              fields {
                id
                slug
              }
              tableOfContents
              internal {
                contentFilePath
              }
            }
          }
        }
      }
    `
  );
  if (result.errors) {
    reporter.panic('error loading content', result.errors);
    return;
  }

  const docsTemplate = path.join(__dirname, 'src/templates/docs.js');
  result.data.allMdx.edges.forEach(({ node }) => {
    actions.createPage({
      path: node.fields.slug ? node.fields.slug : '/',
      component: `${docsTemplate}?__contentFilePath=${node.internal.contentFilePath}`,
      context: {
        id: node.fields.id
      }
    });
  });
};

exports.onCreateNode = ({ node, getNode, actions, reporter }, themeOptions) => {
  const { createNodeField } = actions;
  const { useLegacyUrls = false } = themeOptions;

  if (node.internal.type === 'Mdx') {
    const parent = getNode(node.parent);
    const title = node.frontmatter.title || startCase(parent.name)

    let value =  node.frontmatter.slug;
    if(!value && parent.relativePath){
      value = parent.relativePath.replace(parent.ext, '');
    }

    if (!value) {
      reporter.panic(`Can not create node with title: ${title} there is no relative path or frontmatter to set the "slug" field`);
      return;
    }

    let slug = `/${value}`
    if (useLegacyUrls) {
      slug = `/${value}/index.html`
    }

    if (value === 'index') {
      slug = '/';
    }

    createNodeField({
      name: 'slug',
      node,
      value: slug
    });

    createNodeField({
      name: 'id',
      node,
      value: node.id
    });

    createNodeField({
      name: 'title',
      node,
      value: title
    });
  }
};

exports.pluginOptionsSchema = ({ Joi }) => {
  return Joi.object({
    useLegacyUrls: Joi.boolean().description(`Use legacy URLs with /index.html`)
  });
};

==> gatsby-theme-platformos-docskit-1.1.0.tgz: package/gatsby-node.js <==
/**
 * Implement Gatsby's Node APIs in this file.
 *
 * See: https://www.gatsbyjs.com/docs/reference/config-files/gatsby-node/
 */

/**
 * @type {import('gatsby').GatsbyNode['createPages']}
 */
const path = require('path');
const startCase = str => str.replace(/([A-Z])/g, ' $1').replace(/^./, str => str.toUpperCase());

exports.createPages = async ({ actions, graphql, reporter }) => {
  const result = await graphql(
    `
      {
        allMdx(filter: {fields: {source: {eq: "content"}}}) {
          edges {
            node {
              fields {
                id
                slug
              }
              tableOfContents
              internal {
                contentFilePath
              }
            }
          }
        }
      }
    `
  );
  if (result.errors) {
    reporter.panic('error loading content', result.errors);
    return;
  }

  const docsTemplate = path.join(__dirname, 'src/templates/docs.js');
  result.data.allMdx.edges.forEach(({ node }) => {
    actions.createPage({
      path: node.fields.slug ? node.fields.slug : '/',
      component: `${docsTemplate}?__contentFilePath=${node.internal.contentFilePath}`,
      context: {
        id: node.fields.id
      }
    });
  });
};

exports.onCreateNode = ({ node, getNode, actions, reporter }, themeOptions) => {
  const { createNodeField } = actions;
  const { useLegacyUrls = false } = themeOptions;

  if (node.internal.type === 'Mdx') {
    const parent = getNode(node.parent);
    const title = node.frontmatter.title || startCase(parent.name)

    let value =  node.frontmatter.slug;
    if(!value && parent.relativePath){
      value = parent.relativePath.replace(parent.ext, '');
    }

    if (!value) {
      reporter.panic(`Can not create node with title: ${title} there is no relative path or frontmatter to set the "slug" field`);
      return;
    }

    let slug = `/${value}`
    if (useLegacyUrls) {
      slug = `/${value}/index.html`
    }

    if (value === 'index') {
      slug = '/';
    }

    createNodeField({
      name: 'slug',
      node,
      value: slug
    });

    createNodeField({
      name: 'id',
      node,
      value: node.id
    });

    createNodeField({
      name: 'title',
      node,
      value: title
    });
  }
};
exports.createSchemaCustomization = ({ actions }) => {
  const { createTypes } = actions

  createTypes(`
    type Mdx implements Node {
      frontmatter: MdxFrontmatter!
    }
    type MdxFrontmatter {
      hideNavigation: Boolean
      hideToc: Boolean
    }
  `)
}

exports.pluginOptionsSchema = ({ Joi }) => {
  return Joi.object({
    useLegacyUrls: Joi.boolean().description(`Use legacy URLs with /index.html`),
    showFullNavigation: Joi.boolean().description(`Always show full navigation on every page`)
  });
};
